==> apache-pulsar-2.8.3-src.tar.gz: apache-pulsar-2.8.3-src/pulsar-transaction/coordinator/src/main/java/org/apache/pulsar/transaction/coordinator/TransactionSubscription.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.transaction.coordinator;

import com.google.common.base.Objects;
import lombok.Builder;
import lombok.Data;

/**
 * A class for representing acked topic subscription info.
 */
@Data
@Builder
public class TransactionSubscription implements Comparable<TransactionSubscription> {

    private String topic;
    private String subscription;

    @Override
    public int hashCode() {
        return Objects.hashCode(topic, subscription);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TransactionSubscription that = (TransactionSubscription) o;
        return topic.equals(that.topic)
                && subscription.equals(that.subscription);
    }

    @Override
    public int compareTo(TransactionSubscription o) {
        int topicCompare = topic.compareTo(o.topic);
        if (topicCompare == 0) {
            return subscription.compareTo(o.subscription);
        }
        return topicCompare;
    }
}

==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/pulsar-transaction/coordinator/src/main/java/org/apache/pulsar/transaction/coordinator/TransactionSubscription.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.transaction.coordinator;

import java.util.Objects;
import lombok.Builder;
import lombok.Data;

/**
 * A class for representing acked topic subscription info.
 */
@Data
@Builder
public class TransactionSubscription implements Comparable<TransactionSubscription> {

    private String topic;
    private String subscription;

    @Override
    public int hashCode() {
        return Objects.hash(topic, subscription);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TransactionSubscription that = (TransactionSubscription) o;
        return topic.equals(that.topic)
                && subscription.equals(that.subscription);
    }

    @Override
    public int compareTo(TransactionSubscription o) {
        int topicCompare = topic.compareTo(o.topic);
        if (topicCompare == 0) {
            return subscription.compareTo(o.subscription);
        }
        return topicCompare;
    }
}
